@@ -171,7 +171,7 @@ def main_standalone( argc, argv ):
         pimple, nOuterCorr, nCorr, nNonOrthCorr, momentumPredictor, transonic = readPIMPLEControls( mesh )
 
         from Foam.finiteVolume.cfdTools.general.include import CourantNo
-        CoNum, meanCoNum, velMag = CourantNo( mesh, phi, runTime )
+        CoNum, meanCoNum = CourantNo( mesh, phi, runTime )
       
         from Foam.finiteVolume.cfdTools.general.include import setDeltaT
         runTime = setDeltaT( runTime, adjustTimeStep, maxCo, maxDeltaT, CoNum )
@@ -211,8 +211,8 @@ def main_standalone( argc, argv ):
 
 
 #--------------------------------------------------------------------------------------
-from Foam import FOAM_BRANCH_VERSION
-if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
+from Foam import FOAM_REF_VERSION
+if FOAM_REF_VERSION( ">=", "010600" ):
    if __name__ == "__main__" :
       import sys, os
       argv = sys.argv
@@ -224,6 +224,5 @@ else:
    ext_Info() << "\n\n To use this solver it is necessary to SWIG OpenFOAM-1.6 or higher\n"
    pass
 
-    
-#--------------------------------------------------------------------------------------
 
+#--------------------------------------------------------------------------------------
